ERCOT Realtime Settlement Point price retrieval library
=================================================================================

Library to extract Realtime settlement data from ERCOT (www.ercot.com).

Retrieves the current day realtime settlement prices from ERCOT.

Check out `ERCOT's website <https://www.ercot.com>`__.
